The matchers
============

We have a plethora of matchers here. Likely you don't need them and are happy
with the flexible minimum described in :doc:`any-and-ellipses`.

Basically all projects use ``...`` regularly, and only a few projects use one
of the matchers below at all. We have them to make matching expressive, not so
that you have to use them. ;-)

.. automodule:: mockito.matchers
   :members:
